# Altspell Refaurmd Lojikl Inglish

Refaurmd Lojikl Inglish plugin for altspell.

## Licensing

The [Refaurmd Lojikl Inglish CSV file](/src/altspell_refaurmd_lojikl_inglish/data/refaurmd-lojikl-inglish-dict.csv) is adapted from the [Refaurmd Lojikl Inglish dictionary](https://github.com/njohnson-oss/wyrdplay-converter/blob/master/Dictionaries/RLI.dict) by Alan Beale, used under [CC BY SA 4.0](/licenses/CC-BY-SA-4.0.txt). The [Refaurmd Lojikl Inglish CSV file](/src/altspell_refaurmd_lojikl_inglish/data/refaurmd-lojikl-inglish-dict.csv) is licensed under [CC BY SA 4.0](/licenses/CC-BY-SA-4.0.txt) by Nicholas Johnson.
